@@ -271,8 +271,22 @@ class DeltaTable:
         dbutils.fs.rm(self.checkpoint_base_path, recurse=True)
 
     def read_stream(self, spark: SparkSession, **kw):
-        """
-        read in the stream to a dataframe
+        """Read in a stream of cloud files to a dataframe
+
+        Parameters:
+        spark (SparkSession): SparkSession
+        **kw: keyword arguments to pass to spark.readStream.format('cloudFiles').load()
+            Databricks has documentation on different parameters here:
+                https://docs.databricks.com/ingestion/auto-loader/options.html
+            However, these are the parameters currently supported by delta-table-helpers:
+                cloudFiles_format (str): format of cloud files (e.g. 'csv', 'parquet')
+                header (bool): whether the cloud files have a header row (default: 'true')
+                multiLine (bool): whether the cloud files have multiple lines (default: 'true')
+                escape (str): escape character (default: "\"")
+                badRecordsPath (str): path to write bad records to (default: '/tmp/{schema_name}/{table_name}/bad_records')
+                maxFilesPerTrigger (int): max number of files to process per trigger (default: 1000)
+                    references: https://docs.databricks.com/structured-streaming/delta-lake.html#limit-input-rate
+
         """
 
         format = kw.get('cloudFiles_format') or 'csv'
@@ -280,10 +294,12 @@ class DeltaTable:
         multiline = kw.get('multiLine') or 'true'
         escape = kw.get('escape') or "\""
         bad_records_path = kw.get('badRecordsPath') or f"/tmp/{self.schema_name}/{self.table_name}/bad_records"
+        max_files_per_trigger = kw.get('maxFilesPerTrigger') or 1000
 
         if format == 'csv':
             df = spark.readStream.format('cloudFiles') \
                 .schema(self.file_table_schema) \
+                .option('maxFilesPerTrigger', max_files_per_trigger) \
                 .option('cloudFiles.format', format) \
                 .option('header', header) \
                 .option('multiLine', multiline) \
@@ -293,6 +309,7 @@ class DeltaTable:
         else:
             df = spark.readStream.format('cloudFiles') \
                 .schema(self.file_table_schema) \
+                .option('maxFilesPerTrigger', max_files_per_trigger) \
                 .option('cloudFiles.format', format) \
                 .option('header', header) \
                 .option("cloudFiles.schemaLocation", self.checkpoint_path) \
@@ -314,11 +331,12 @@ class DeltaTable:
 
 
     def stream(self, spark: SparkSession, **kw) -> None:
-        """
-        stream data from s3 to a delta table
+        """Uses Auto Loader to stream data from s3 to a delta table
 
         References:
+            + https://docs.databricks.com/ingestion/auto-loader/
             + https://hackersandslackers.com/structured-streaming-in-pyspark/
+            + https://medium.com/analytics-vidhya/apache-spark-structured-streaming-with-pyspark-b4a054a7947d
         """
         log_msg = LogMessage()
         log_msg.add('summary', f"uploading {self.schema_name}.{self.table_name} to a delta table using AutoLoader")
